@@ -32,9 +32,16 @@ module Gitlab
       InvalidRef = Class.new(StandardError)
       GitError = Class.new(StandardError)
       DeleteBranchError = Class.new(StandardError)
-      CreateTreeError = Class.new(StandardError)
       TagExistsError = Class.new(StandardError)
 
+      class CreateTreeError < StandardError
+        attr_reader :error
+
+        def initialize(error)
+          @error = error
+        end
+      end
+
       class << self
         def from_gitaly(gitaly_repository, call)
           new(
@@ -206,14 +213,6 @@ module Gitlab
         end
       end
 
-      def write_config(full_path:)
-        return unless full_path.present?
-
-        raise NoRepository, 'repository does not exist' unless exists?
-
-        rugged.config['gitlab.fullpath'] = full_path
-      end
-
       def ancestor?(from, to)
         return false if from.nil? || to.nil?
 
@@ -320,7 +319,6 @@ module Gitlab
         ) do |start_commit|
 
           revert_tree_id = check_revert_content(commit, start_commit.sha)
-          raise CreateTreeError unless revert_tree_id
 
           committer = user_to_committer(user)
 
@@ -360,7 +358,16 @@ module Gitlab
           remote_repo_path = remote_repository.path
         end
 
-        with_worktree(worktree, branch, env: env) do
+        diff_range = "#{branch}...#{remote_branch}"
+        diff_files = begin
+                       run_git!(
+                         %W[diff --name-only #{diff_range}]
+                       ).chomp
+                     rescue GitError
+                       []
+                     end
+
+        with_worktree(worktree, branch, sparse_checkout_files: diff_files, env: env) do
           run_git!(
             %W[pull --rebase #{remote_repo_path} #{remote_branch}],
             chdir: worktree.path, env: env, include_stderr: true
@@ -667,7 +674,8 @@ module Gitlab
         nil
       end
 
-      def commit(ref = 'HEAD')
+      def commit(ref = nil)
+        ref ||= root_ref
         Gitlab::Git::Commit.find(self, ref)
       end
 
@@ -777,10 +785,10 @@ module Gitlab
         args << { mainline: 1 } if target_commit.merge_commit?
 
         revert_index = rugged.revert_commit(*args)
-        return false if revert_index.conflicts?
+        raise CreateTreeError, :conflict if revert_index.conflicts?
 
         tree_id = revert_index.write_tree(rugged)
-        return false unless diff_exists?(source_sha, tree_id)
+        raise CreateTreeError, :empty unless diff_exists?(source_sha, tree_id)
 
         tree_id
       end
@@ -818,7 +826,6 @@ module Gitlab
         ) do |start_commit|
 
           cherry_pick_tree_id = check_cherry_pick_content(commit, start_commit.sha)
-          raise CreateTreeError unless cherry_pick_tree_id
 
           committer = user_to_committer(user)
 
@@ -839,10 +846,10 @@ module Gitlab
         args << 1 if target_commit.merge_commit?
 
         cherry_pick_index = rugged.cherrypick_commit(*args)
-        return false if cherry_pick_index.conflicts?
+        raise CreateTreeError, :conflict if cherry_pick_index.conflicts?
 
         tree_id = cherry_pick_index.write_tree(rugged)
-        return false unless diff_exists?(source_sha, tree_id)
+        raise CreateTreeError, :empty unless diff_exists?(source_sha, tree_id)
 
         tree_id
       end
